diff --git a/src/ipa/rpi/controller/controller.cpp b/src/ipa/rpi/controller/controller.cpp
index 14d245da2ce7..4b6f82b41916 100644
--- a/src/ipa/rpi/controller/controller.cpp
+++ b/src/ipa/rpi/controller/controller.cpp
@@ -34,7 +34,8 @@ static const std::map<std::string, Controller::HardwareConfig> HardwareConfigMap
 			.focusRegions = { 4, 3 },
 			.numHistogramBins = 128,
 			.numGammaPoints = 33,
-			.pipelineWidth = 13
+			.pipelineWidth = 13,
+			.statsInline = false,
 		}
 	},
 };
diff --git a/src/ipa/rpi/controller/controller.h b/src/ipa/rpi/controller/controller.h
index c6af5cd6c7d4..a8bc61880ab4 100644
--- a/src/ipa/rpi/controller/controller.h
+++ b/src/ipa/rpi/controller/controller.h
@@ -45,6 +45,7 @@ public:
 		unsigned int numHistogramBins;
 		unsigned int numGammaPoints;
 		unsigned int pipelineWidth;
+		bool statsInline;
 	};
 
 	Controller();

diff --git a/src/ipa/rpi/common/ipa_base.cpp b/src/ipa/rpi/common/ipa_base.cpp
index 97f647a9e53e..f28eb36b7a44 100644
--- a/src/ipa/rpi/common/ipa_base.cpp
+++ b/src/ipa/rpi/common/ipa_base.cpp
@@ -429,11 +429,10 @@ void IpaBase::prepareIsp(const PrepareParams &params)
 	}
 
 	/*
 	 * If a statistics buffer has been passed in, call processStats
 	 * directly now before prepare() since the statistics are available in-line
 	 * with the Bayer frame.
 	 */
-	if (params.buffers.stats)
+	if (controller_.getHardwareConfig().statsInline)
 		processStats({ params.buffers, params.ipaContext });
 
 	/* Do we need/want to call prepare? */
@@ -445,6 +444,10 @@ void IpaBase::prepareIsp(const PrepareParams &params)
 
 	frameCount_++;
 
+	/* If the statistics are inline the metadata can be returned early. */
+	if (controller_.getHardwareConfig().statsInline)
+		reportMetadata(ipaContext);
+
 	/* Ready to push the input buffer into the ISP. */
 	prepareIspComplete.emit(params.buffers, false);
 }
@@ -479,7 +482,13 @@ void IpaBase::processStats(const ProcessParams &params)
 		}
 	}
 
-	reportMetadata(ipaContext);
+	/*
+	 * If the statistics are not inline the metadata must be returned now,
+	 * before the processStatsComplete signal.
+	 */
+	if (!controller_.getHardwareConfig().statsInline)
+		reportMetadata(ipaContext);
+
 	processStatsComplete.emit(params.buffers);
 }
 
@@ -429,11 +429,10 @@ void IpaBase::prepareIsp(const PrepareParams &params)
 
 	/*
-	 * If a statistics buffer has been passed in, call processStats
-	 * directly now before prepare() since the statistics are available in-line
-	 * with the Bayer frame.
+	 * If the statistics are inline (i.e. already available with the Bayer
+	 * frame), call processStats() now before prepare().
 	 */